
import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": "96940", "country_code": "PW", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Palau"}]'