
import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": "AD100", "country_code": "AD", "admin_code1": "02", "admin_name1": "Canillo", "admin_name2": null, "admin_name3": null, "place_name": "Canillo"}, {"postal_code": "AD200", "country_code": "AD", "admin_code1": "03", "admin_name1": "Encamp", "admin_name2": null, "admin_name3": null, "place_name": "Encamp"}, {"postal_code": "AD400", "country_code": "AD", "admin_code1": "04", "admin_name1": "La Massana", "admin_name2": null, "admin_name3": null, "place_name": "La Massana"}, {"postal_code": "AD300", "country_code": "AD", "admin_code1": "05", "admin_name1": "Ordino", "admin_name2": null, "admin_name3": null, "place_name": "Ordino"}, {"postal_code": "AD600", "country_code": "AD", "admin_code1": "06", "admin_name1": "Sant Juli\u00e0 de L\u00f2ria", "admin_name2": null, "admin_name3": null, "place_name": "Sant Juli\u00e0 de L\u00f2ria"}, {"postal_code": "AD500", "country_code": "AD", "admin_code1": "07", "admin_name1": "Andorra la Vella", "admin_name2": null, "admin_name3": null, "place_name": "Andorra la Vella"}, {"postal_code": "AD700", "country_code": "AD", "admin_code1": "08", "admin_name1": "Escaldes-Engordany", "admin_name2": null, "admin_name3": null, "place_name": "Escaldes-Engordany"}]'