
import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": 120, "country_code": "VA", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Citta Del Vaticano"}]'