
import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": "9490", "country_code": "LI", "admin_code1": "7001", "admin_name1": "Vaduz", "admin_name2": null, "admin_name3": null, "place_name": "Vaduz"}, {"postal_code": "9495", "country_code": "LI", "admin_code1": "7002", "admin_name1": "Triesen", "admin_name2": null, "admin_name3": null, "place_name": "Triesen"}, {"postal_code": "9496", "country_code": "LI", "admin_code1": "7003", "admin_name1": "Balzers", "admin_name2": null, "admin_name3": null, "place_name": "Balzers"}, {"postal_code": "9497", "country_code": "LI", "admin_code1": "7004", "admin_name1": "Triesenberg", "admin_name2": null, "admin_name3": null, "place_name": "Triesenberg"}, {"postal_code": "9494", "country_code": "LI", "admin_code1": "7005", "admin_name1": "Schaan", "admin_name2": null, "admin_name3": null, "place_name": "Schaan"}, {"postal_code": "9498", "country_code": "LI", "admin_code1": "7006", "admin_name1": "Planken", "admin_name2": null, "admin_name3": null, "place_name": "Planken"}, {"postal_code": "9485", "country_code": "LI", "admin_code1": "7007", "admin_name1": "Eschen", "admin_name2": null, "admin_name3": null, "place_name": "Nendeln"}, {"postal_code": "9492", "country_code": "LI", "admin_code1": "7007", "admin_name1": "Eschen", "admin_name2": null, "admin_name3": null, "place_name": "Eschen"}, {"postal_code": "9486", "country_code": "LI", "admin_code1": "7008", "admin_name1": "Mauren", "admin_name2": null, "admin_name3": null, "place_name": "Schaanwald"}, {"postal_code": "9493", "country_code": "LI", "admin_code1": "7008", "admin_name1": "Mauren", "admin_name2": null, "admin_name3": null, "place_name": "Mauren FL"}, {"postal_code": "9487", "country_code": "LI", "admin_code1": "7009", "admin_name1": "Gamprin", "admin_name2": null, "admin_name3": null, "place_name": "Gamprin-Bendern"}, {"postal_code": "9491", "country_code": "LI", "admin_code1": "7010", "admin_name1": "Ruggell", "admin_name2": null, "admin_name3": null, "place_name": "Ruggell"}, {"postal_code": "9488", "country_code": "LI", "admin_code1": "7011", "admin_name1": "Schellenberg", "admin_name2": null, "admin_name3": null, "place_name": "Schellenberg"}]'