
import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": 97605, "country_code": "YT", "admin_code1": "00", "admin_name1": "Mayotte (general)", "admin_name2": null, "admin_name3": null, "place_name": "Passamainty"}, {"postal_code": 97630, "country_code": "YT", "admin_code1": "97601", "admin_name1": "Acoua", "admin_name2": null, "admin_name3": null, "place_name": "Acoua"}, {"postal_code": 97650, "country_code": "YT", "admin_code1": "97602", "admin_name1": "Bandraboua", "admin_name2": null, "admin_name3": null, "place_name": "Bandraboua"}, {"postal_code": 97660, "country_code": "YT", "admin_code1": "97603", "admin_name1": "Bandrele", "admin_name2": null, "admin_name3": null, "place_name": "Bandr\u00e9l\u00e9"}, {"postal_code": 97620, "country_code": "YT", "admin_code1": "97604", "admin_name1": "Bou\u00e9ni", "admin_name2": null, "admin_name3": null, "place_name": "Bou\u00e9ni"}, {"postal_code": 97670, "country_code": "YT", "admin_code1": "97605", "admin_name1": "Chiconi", "admin_name2": null, "admin_name3": null, "place_name": "Chiconi"}, {"postal_code": 97620, "country_code": "YT", "admin_code1": "97606", "admin_name1": "Chirongui", "admin_name2": null, "admin_name3": null, "place_name": "Chirongui"}, {"postal_code": 97660, "country_code": "YT", "admin_code1": "97607", "admin_name1": "Dembeni", "admin_name2": null, "admin_name3": null, "place_name": "Dembeni"}, {"postal_code": 97615, "country_code": "YT", "admin_code1": "97608", "admin_name1": "Dzaoudzi", "admin_name2": null, "admin_name3": null, "place_name": "Dzaoudzi"}, {"postal_code": 97625, "country_code": "YT", "admin_code1": "97609", "admin_name1": "Kani-K\u00e9li", "admin_name2": null, "admin_name3": null, "place_name": "Kani K\u00e9li"}, {"postal_code": 97600, "country_code": "YT", "admin_code1": "97610", "admin_name1": "Koungou", "admin_name2": null, "admin_name3": null, "place_name": "Koungou"}, {"postal_code": 97600, "country_code": "YT", "admin_code1": "97611", "admin_name1": "Mamoudzou", "admin_name2": null, "admin_name3": null, "place_name": "Mamoudzou"}, {"postal_code": 97605, "country_code": "YT", "admin_code1": "97611", "admin_name1": "Mamoudzou", "admin_name2": null, "admin_name3": null, "place_name": "Mamoudzou"}, {"postal_code": 97650, "country_code": "YT", "admin_code1": "97611", "admin_name1": "Mamoudzou", "admin_name2": null, "admin_name3": null, "place_name": "Mamoudzou"}, {"postal_code": 97680, "country_code": "YT", "admin_code1": "97611", "admin_name1": "Mamoudzou", "admin_name2": null, "admin_name3": null, "place_name": "Mamoudzou"}, {"postal_code": 97630, "country_code": "YT", "admin_code1": "97612", "admin_name1": "Mtsamboro", "admin_name2": null, "admin_name3": null, "place_name": "Mtsamboro"}, {"postal_code": 97650, "country_code": "YT", "admin_code1": "97613", "admin_name1": "MTsangamouji", "admin_name2": null, "admin_name3": null, "place_name": "MTsangamouji"}, {"postal_code": 97670, "country_code": "YT", "admin_code1": "97614", "admin_name1": "Ouangani", "admin_name2": null, "admin_name3": null, "place_name": "Ouangani"}, {"postal_code": 97615, "country_code": "YT", "admin_code1": "97615", "admin_name1": "Pamandzi", "admin_name2": null, "admin_name3": null, "place_name": "Pamandzi"}, {"postal_code": 97640, "country_code": "YT", "admin_code1": "97616", "admin_name1": "Sada", "admin_name2": null, "admin_name3": null, "place_name": "Sada"}, {"postal_code": 97680, "country_code": "YT", "admin_code1": "97617", "admin_name1": "Tsingoni", "admin_name2": null, "admin_name3": null, "place_name": "Tsingoni"}]'