
import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": "96799", "country_code": "AS", "admin_code1": null, "admin_name1": "As", "admin_name2": null, "admin_name3": null, "place_name": "Pago Pago"}]'