
import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": 98610, "country_code": "WF", "admin_code1": "98611", "admin_name1": "Circonscription dAlo", "admin_name2": null, "admin_name3": null, "place_name": "Alo"}, {"postal_code": 98620, "country_code": "WF", "admin_code1": "98612", "admin_name1": "Circonscription de Sigave", "admin_name2": null, "admin_name3": null, "place_name": "Sigave"}, {"postal_code": 98600, "country_code": "WF", "admin_code1": "98613", "admin_name1": "Circonscription dUv\u00e9a", "admin_name2": null, "admin_name3": null, "place_name": "Uv\u00e9a"}]'