
import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": "96944", "country_code": "FM", "admin_code1": "01", "admin_name1": "State of Kosrae", "admin_name2": null, "admin_name3": null, "place_name": "Kosrae"}, {"postal_code": "96941", "country_code": "FM", "admin_code1": "02", "admin_name1": "State of Pohnpei", "admin_name2": null, "admin_name3": null, "place_name": "Pohnpei"}, {"postal_code": "96942", "country_code": "FM", "admin_code1": "03", "admin_name1": "State of Chuuk", "admin_name2": null, "admin_name3": null, "place_name": "Chuuk"}, {"postal_code": "96943", "country_code": "FM", "admin_code1": "04", "admin_name1": "State of Yap", "admin_name2": null, "admin_name3": null, "place_name": "Yap"}]'