
import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": "96960", "country_code": "MH", "admin_code1": "68", "admin_name1": "Marshall Islands", "admin_name2": "Ailinginae", "admin_name3": null, "place_name": "Majuro"}, {"postal_code": "96970", "country_code": "MH", "admin_code1": "68", "admin_name1": "Marshall Islands", "admin_name2": "Ailinginae", "admin_name3": null, "place_name": "Ebeye"}]'