
import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": "96951", "country_code": "MP", "admin_code1": "100", "admin_name1": "Rota", "admin_name2": null, "admin_name3": null, "place_name": "Rota"}, {"postal_code": "96950", "country_code": "MP", "admin_code1": "110", "admin_name1": "Saipan", "admin_name2": null, "admin_name3": null, "place_name": "Saipan"}, {"postal_code": "96952", "country_code": "MP", "admin_code1": "120", "admin_name1": "Tinian", "admin_name2": null, "admin_name3": null, "place_name": "Tinian"}]'