
import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": 820, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Croix", "admin_name3": null, "place_name": "Christiansted"}, {"postal_code": 821, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Croix", "admin_name3": null, "place_name": "Christiansted"}, {"postal_code": 822, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Croix", "admin_name3": null, "place_name": "Christiansted"}, {"postal_code": 823, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Croix", "admin_name3": null, "place_name": "Christiansted"}, {"postal_code": 824, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Croix", "admin_name3": null, "place_name": "Christiansted"}, {"postal_code": 840, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Croix", "admin_name3": null, "place_name": "Frederiksted"}, {"postal_code": 841, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Croix", "admin_name3": null, "place_name": "Frederiksted"}, {"postal_code": 850, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Croix", "admin_name3": null, "place_name": "Kingshill"}, {"postal_code": 851, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Croix", "admin_name3": null, "place_name": "Kingshill"}, {"postal_code": 830, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. John", "admin_name3": null, "place_name": "St John"}, {"postal_code": 831, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. John", "admin_name3": null, "place_name": "St John"}, {"postal_code": 801, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Thomas", "admin_name3": null, "place_name": "St Thomas"}, {"postal_code": 802, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Thomas", "admin_name3": null, "place_name": "St Thomas"}, {"postal_code": 803, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Thomas", "admin_name3": null, "place_name": "St Thomas"}, {"postal_code": 804, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Thomas", "admin_name3": null, "place_name": "St Thomas"}, {"postal_code": 805, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Thomas", "admin_name3": null, "place_name": "St Thomas"}]'