
import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": "47890", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "San Marino"}, {"postal_code": "47890", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Casole"}, {"postal_code": "47890", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Murata"}, {"postal_code": "47890", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Santa Mustiola"}, {"postal_code": "47891", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Galazzano"}, {"postal_code": "47891", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Falciano"}, {"postal_code": "47891", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Dogana"}, {"postal_code": "47891", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Rovereta"}, {"postal_code": "47892", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Acquaviva"}, {"postal_code": "47892", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Gualdicciolo"}, {"postal_code": "47893", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Ventoso"}, {"postal_code": "47893", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Valdragone"}, {"postal_code": "47893", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "San Giovanni"}, {"postal_code": "47893", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Cailungo"}, {"postal_code": "47893", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Ca Rigo"}, {"postal_code": "47893", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Borgo Maggiore"}, {"postal_code": "47894", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Teglio"}, {"postal_code": "47894", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Chiesanuova"}, {"postal_code": "47895", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Torraccia"}, {"postal_code": "47895", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Domagnano"}, {"postal_code": "47896", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Faetano"}, {"postal_code": "47897", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Fiorentino"}, {"postal_code": "47898", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Montegiardino"}, {"postal_code": "47898", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Cerbaiola"}, {"postal_code": "47899", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Serravalle"}, {"postal_code": "47899", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Fiorina"}]'